@@ -1,4 +1,4 @@
-/* $Id: udpkg.c 11641 2004-03-21 21:13:08Z joeyh $ */
+/* $Id: udpkg.c 20745 2004-09-03 20:12:46Z joeyh $ */
 #include "udpkg.h"
 
 #include <errno.h>
@@ -105,9 +105,9 @@ static int dpkg_doconfigure(struct package_t *pkg)
 		if ((r = di_exec_shell_log(buf)) != 0)
 		{
 			FPRINTF(stderr, "%s's postinst exited with status %d\n",
-				pkg->package, WEXITSTATUS(r));
+				pkg->package, di_exec_mangle_status(r));
 			pkg->status |= STATUS_STATUSHALFCONFIGURED;
-			return WEXITSTATUS(r);
+			return di_exec_mangle_status(r);
 		}
 	}
 
